# gBoost Corona SDK

***

# 利用準備

* gBoost にて、あなたのアプリを登録して `アプリシグネチャ` を取得します。
* 最新の [gBoost Corona SDK](https://d1v5lzukivvtjw.cloudfront.net/sdk/corona/gboost.lua) をダウンロードします。

***

# 設定

`gBoost Corona SDK` を利用する際は、必ず `gboost.lua` を読み込む設定が必要になります。

```lua
local Gboost = require("gboost.lua")
```

***

# セッション開始

広告を表示する前提条件として、`アプリシグネチャ` を利用して、セッションを開始する必要があります。

```lua
Gboost.startSession({
  ios     = "35b78d8e83d13c0b0e988ae7bba4f25e",
  android = "d307724d58afa35e983bd3b1033eadc8"
})
```

***

# テスト広告配信

gBoost にて、`テスト広告配信` を `ON` にしているアプリの場合、テスト用の広告を表示する事が可能です。
`gBoost Corona SDK` を初めて組み込むアプリの場合、テスト広告を配信して正しく SDK が設定されているか、動作しているかを確認するのに役立ちます。

また、テスト広告配信中のアプリはテスティングモードとなり、広告の表示回数やクリック回数、インストール回数のカウントアップは行われなません。

***

# アイコン広告

アプリアイコンを表示する広告です。
サイズが小さく、表示する位置を自由に決められるため、限られたわずかなスペースでも設置する事が可能です。

## 広告キャッシュ

広告をキャッシュします。
広告表示をする前に、事前に広告をキャッシュしておく事で、初回の広告の表示を素早く行う事が可能になります。
必須ではありませんが、実装する事をお勧めします。

```lua
Gboost.cacheIcon()
```

## 広告表示

広告を表示します。

* 指定された `left`、`top`、`right`、`bottom` の位置に広告を表示します。
  * 左上基点にしたい場合は、`left`、`top` を指定します。
  * 右上基点にしたい場合は、`right`、`top` を指定します。
  * 左下基点にしたい場合は、`left`、`bottom` を指定します。
  * 右下基点にしたい場合は、`right`、`bottom` を指定します。
* 指定された `intervalTime` ミリ秒間隔で広告の自動更新を行います。

```lua
-- 5秒間隔で自動更新、左上基点で広告を表示
Gboost.showIcon({
  intervalTime = 5000,
  left         = 10,
  top          = 10
})
```

```lua
-- 10秒間隔で自動更新、右下基点で広告を表示
Gboost.showIcon({
  intervalTime = 10000,
  right        = 10,
  bottom       = 10
})
```

## 広告非表示

広告を非表示にします。
表示された広告は、明示的に非表示にしない限り、表示されたままとなるため、必ず非表示の実装が必要となります。

```lua
Gboost.hideIcon()
```

***

# 中型バナー広告

中型のバナーを表示する広告です。
通常のバナーに比べて高さがあるため、常時表示しておくような使い方よりも、ピンポイントで利用する方が効果的です。

## 広告キャッシュ

広告をキャッシュします。
広告表示をする前に、事前に広告をキャッシュしておく事で、初回の広告の表示を素早く行う事が可能になります。
必須ではありませんが、実装する事をお勧めします。

```lua
Gboost.cacheMediumBanner()
```

## 広告表示

広告を表示します。

* 指定された `left`、`top`、`right`、`bottom` の位置に広告を表示します。
  * 左上基点にしたい場合は、`left`、`top` を指定します。
  * 右上基点にしたい場合は、`right`、`top` を指定します。
  * 左下基点にしたい場合は、`left`、`bottom` を指定します。
  * 右下基点にしたい場合は、`right`、`bottom` を指定します。
* 指定された `intervalTime` ミリ秒間隔で広告の自動更新を行います。

```lua
-- 5秒間隔で自動更新、左上基点で広告を表示
Gboost.showMediumBanner({
  intervalTime = 5000,
  left         = 0,
  top          = 0
})
```

```lua
-- 10秒間隔で自動更新、左下基点で広告を表示
Gboost.showMediumBanner({
  intervalTime = 10000,
  left         = 0,
  bottom       = 0
})
```

## 広告非表示

広告を非表示にします。
表示された広告は、明示的に非表示にしない限り、表示されたままとなるため、必ず非表示の実装が必要となります。

``` lua
-- Hide medium banner
Gboost.hideMediumBanner()
```

***

# フルページ広告

フルページのバナーを表示する広告です。
最も `eCPM` が高く、ピンポイントで利用すると効果的です。

## 広告キャッシュ

広告をキャッシュします。
広告表示をする前に、事前に広告をキャッシュしておく事で、初回の広告の表示を素早く行う事が可能になります。
必須ではありませんが、実装する事をお勧めします。

```lua
Gboost.cacheFullpage()
```

## 広告表示

広告を表示します。

* フルページ広告に付随する `閉じるボタン` が押下された際のコールバック関数を指定する事が可能です。

```lua
-- コールバック関数
local function callback(event)
end

-- 広告を表示
Gboost.showFullpage(callback)
```

***

# オススメアプリ一覧ページ

オススメアプリ一覧ページを表示します。
複数アプリのアイコンと名前、説明が一覧になっており、セルクリック、または、インストールボタン押下で App Store / Google Play へ誘導します。

## ページ表示

オススメアプリ一覧ページを表示します。

```lua
Gboost.showRecommend()
```

***

# ダウンロード

[gboost-0.1.0](https://d1v5lzukivvtjw.cloudfront.net/sdk/corona/gboost.lua)

## リリースノート

### 0.1.0 - 2012/04/04

* ベータリリース。
